#!/bin/bash

cd $(dirname $(readlink -f $0))

which spark-submit > /dev/null
status=$?
if test $status -ne 0 ; then
    echo ""
    echo "Spark seems not installed in the system; cannot find spark-submit."
    echo "Please install Spark and make sure spark-submit is executable."
    exit 127
fi

#help message
help()
{
    
echo "Usage: $0 [OPTIONS] [INPUT (EDGE LIST FILE)]"
echo "Enumerate triangles in a graph"
echo "  "
echo "  -p[NumColors]            set the number of colors."
echo "  -i                       vertex numbers are in [0:2^31] of range."
echo "  -C[NumCores]             set the number of executor cores to use (default: 1)."
echo "  -A[Algorithm]            set the algorithm (options: base, cd, sc (default))"
echo "  -M[Master]               set master of spark."
echo " "
echo "Example:"
echo "  $0 -C1 -Asc -i path/to/triangle/file"
echo " "
echo " "
}

EXECUTORS="--total-executor-cores 1"
COLORS=
ALGORITHM=sc
LONG=Long
MASTER=

# Execute getopt
ARGS=$(getopt -u -o p:iC:A:M: -- "$@")
set -- $ARGS
while [ $# -gt 0 ]; do
  case "$1" in
    -p)
        COLORS="$2"
        shift;;
    -i)
        LONG=""
         ;;
    -C)
        EXECUTORS="--total-executor-cores $2"
        shift;;
    -A)
        ALGORITHM="$2"
        shift;;
    -M)
        MASTER="--master spark://latte:7077"
        shift;;

    (--) shift;break;;
    (-*) 
        echo "Error: invalid option $1"
        echo "========================================="
        help;
        exit 1;;
    (*) break;;
  esac
  shift
done

if [ $# -eq 0 ];then
    echo "Error: input path is not defined."
    echo "========================================="
    help
    exit 127
fi

INPUT=$1

QUERY="spark-submit $MASTER $EXECUTORS --jars bin/trove-3.0.3.jar --class pteSpark.PTE$LONG bin/pte-spark-1.0.jar $1 $COLORS"
echo spark query: $QUERY
echo =====================
$QUERY
